(Απαιτήσεις εγγράφου: (Όνομα συστήματος) (Στόχος {prompt}) (Απαιτήσεις (Σκοπός "Συνοπτική περιγραφή του συνολικού σκοπού του συστήματος") (Δομή αρχείων/φακέλων (Μορφή "Markdown") (Παραλείψεις "Καμία")) (Διάγραμμα κλάσεων (Περιγραφή "Απεικόνιση των κλάσεων που αποτελούν το σύστημα και των σχέσεών τους") (Μορφή "Χαρακτήρες ASCII") (Πληροφορίες που περιλαμβάνονται (Όνομα κλάσης) (Χαρακτηριστικά) (Λειτουργίες) (Σχέσεις με συσχετιζόμενες κλάσεις))) (Λεπτομέρειες κλάσεων (Πληροφορίες που περιλαμβάνονται (Όνομα κλάσης) (Περιγραφή) (Χαρακτηριστικά (Όνομα) (Τύπος) (Τροποποιητής πρόσβασης)) (Λειτουργίες (Όνομα) (Παράμετροι) (Τιμή επιστροφής) (Τροποποιητής πρόσβασης) (Περιγραφή)) (Σχέσεις με συσχετιζόμενες κλάσεις))) (Περιπτώσεις χρήσης (Περιγραφή "Απαρίθμηση των κύριων περιπτώσεων χρήσης του συστήματος") (Καθορισμός πληροφοριών (Σχετικές κλάσεις) (Σχετικές μέθοδοι))) (Διαγράμματα ακολουθίας (Περιγραφή "Αναπαράσταση των αλληλεπιδράσεων μεταξύ αντικειμένων για τις κύριες λειτουργίες του συστήματος") (Μορφή "Χαρακτήρες ASCII") (Δημιουργία για κάθε περίπτωση χρήσης, 3) (Πληροφορίες που περιλαμβάνονται (Σχετικά αντικείμενα) (Μηνύματα μεταξύ αντικειμένων) (Σειρά μηνυμάτων) (Δομές ελέγχου))) (Αρχές αντικειμενοστραφούς (Εφαρμογή (Ενθυλάκωση) (Κληρονομικότητα) (Πολυμορφισμός)) (Διαχωρισμός ευθυνών μεταξύ κλάσεων)) (Πρότυπα σχεδίασης (Εφαρμογή) (Σκοπός "Βελτίωση ευελιξίας και επεκτασιμότητας")) (Πρόσθετες πληροφορίες "Ανατρέξτε στο [Πρόσθετες πληροφορίες]")) Όσο το δυνατόν πιο λεπτομερής περιγραφή σε επίπεδο επιχειρήσεων, μορφή md, lang ja)